@@ -34,12 +34,12 @@ def sign(name, date, a_hash, position, in_file):
 
 
     signed_page = PyPDF2.PdfFileReader(signed_page_bytes).getPage(0)
-    (page_first_dim, page_second_dim) = page_media.upperRight
 
+    media_3 = float(first_page['/MediaBox'][3])
     if first_page.get('/Rotate', 0) in [90, 270]:
         signed_page.scaleTo(float(first_page['/MediaBox'][3]), float(first_page['/MediaBox'][2]))
     else:
-        signed_page.scaleTo(float(first_page['/MediaBox'][2]), float(first_page['/MediaBox'][3]))
+        signed_page.scaleTo(float(first_page['/MediaBox'][2]), media_3 if media_3 > 0 else float(first_page['/MediaBox'][1]))
 
 
     output_signed_pdf = PyPDF2.PdfFileWriter()
